import Vue from "vue";
import Vuex from "vuex";

Vue.use(Vuex);

export const store = new Vuex.Store({
  state: {
    // 주문자 정보
    name: "",
    phoneNumber: "",
    email: "",
    emailSelfText: "",
    emailLabelText: "선택해주세요",
    showNameError: false,
    showPhoneNumberError: false,
    showEmailError: false,
    hasUserInfo: false,

    // 배송지 정보
    newDeliveryList: [],
    checkDefaultDeliveryInfo: false, // 기본 배송지로 저장
    checkAddDeliveryInfo: false, // 배송지 목록에 추가
    defaultAddress: false,
    deliverySno: 0, // 배송지 고유 번호
    deliveryName: "우리집", // 배송지명
    deliveryUserName: "", // 받는 사람
    deliveryPhoneNumber: "",
    postalCode: "", // 우편번호
    mainAddress: "",
    detailAddress: "",
    deliveryLabelText: "배송시 요청사항을 선택해주세요",
    deliverySelfMessage: "",
    showDeliveryNameError: false,
    showDeliveryUserNameError: false,
    showDeliveryPhoneNumberError: false,
    showAddressError: false,
    hasDeliveryInfo: false,
    useDefaultDeliveryInfo: true, // 기본 배송지 사용 => 배송지 목록에서 기본 배송지가 아닌 다른 배송지를 선택할 경우 false로 변경됨
    addNewDeliveryInfo: false, // 새로운 배송지를 추가한 경우 => 이 경우 기본 배송지로 저장 숨김

    // 사용할 포인트
    usingPoint: 0,

    // 결제수단
    paymentType: "kakaoPay",
    paymentBankInfo: {},

    // 결제정보 확인 체크
    agreeTerms: false,
    showAgreeTermsError: false,
  },
  mutations: {
    updateName(state, value) {
      state.name = value;
    },
    updatePhoneNumber(state, value) {
      state.phoneNumber = value
        .replaceAll("-", "")
        .replace(/[^0-9]/, "")
        .replace(/^(\d{2,3})(\d{3,4})(\d{4})$/, `$1-$2-$3`);
    },
    updateEmail(state, value) {
      state.email = value;
    },
    updateEmailSelfText(state, value) {
      state.emailSelfText = value;
    },
    updateEmailLabelText(state, value) {
      state.emailLabelText = value;
    },
    updateHasUserInfo(state, value) {
      state.hasUserInfo = value;
    },
    updateHasDeliveryInfo(state, value) {
      state.hasDeliveryInfo = value;
    },
    updateUseDefaultDeliveryInfo(state, value) {
      state.useDefaultDeliveryInfo = value;
    },
    updateCheckDefaultDeliveryInfo(state, value) {
      state.checkDefaultDeliveryInfo = value;
    },
    updateCheckAddDeliveryInfo(state, value) {
      state.checkAddDeliveryInfo = value;
    },
    updateDefaultAddress(state, value) {
      state.defaultAddress = value;
    },
    updateAddNewDeliveryInfo(state, value) {
      state.addNewDeliveryInfo = value;
    },
    updateNewDeliveryList(state, value) {
      state.newDeliveryList = value;
    },
    updateDeliverySno(state, value) {
      state.deliverySno = value;
    },
    updateDeliveryName(state, value) {
      state.deliveryName = value;
    },
    updateDeliveryUserName(state, value) {
      state.deliveryUserName = value;
    },
    updateDeliveryPhoneNumber(state, value) {
      state.deliveryPhoneNumber = value
        .replaceAll("-", "")
        .replace(/[^0-9]/, "")
        .replace(/^(\d{2,3})(\d{3,4})(\d{4})$/, `$1-$2-$3`);
    },
    updatePostalCode(state, value) {
      state.postalCode = value;
    },
    updateMainAddress(state, value) {
      state.mainAddress = value;
    },
    updateDetailAddress(state, value) {
      state.detailAddress = value;
    },
    updateDeliveryLabelText(state, value) {
      state.deliveryLabelText = value;
    },
    updateDeliverySelfMessage(state, value) {
      state.deliverySelfMessage = value;
    },
    updateUsingPoint(state, value) {
      state.usingPoint = value;
    },
    updatePaymentType(state, value) {
      state.paymentType = value;
    },
    updatePaymentBankInfo(state, value) {
      state.paymentBankInfo = value;
    },
    updateAgreeTerms(state, value) {
      state.agreeTerms = value;
    },

    // error
    updateNameError(state, value) {
      state.showNameError = value;
    },
    updatePhoneNumberError(state, value) {
      state.showPhoneNumberError = value;
    },
    updateEmailError(state, value) {
      state.showEmailError = value;
    },
    updateDeliveryNameError(state, value) {
      state.showDeliveryNameError = value;
    },
    updateDeliveryUserNameError(state, value) {
      state.showDeliveryUserNameError = value;
    },
    updateDeliveryPhoneNumberError(state, value) {
      state.showDeliveryPhoneNumberError = value;
    },
    updateAddressError(state, value) {
      state.showAddressError = value;
    },
    updateAgreeTermsError(state, value) {
      state.showAgreeTermsError = value;
    },

    // validate
    validateName(state) {
      if (state.name === "") state.showNameError = true;
      else state.showNameError = false;
    },
    validatePhone(state) {
      if (state.phoneNumber === "") state.showPhoneNumberError = true;
      else state.showPhoneNumberError = false;
    },
    validateEmail(state) {
      if (
        state.email === "" ||
        state.emailLabelText === "선택해주세요" ||
        (state.emailLabelText === "직접입력" && state.emailSelfText === "")
      )
        state.showEmailError = true;
      else state.showEmailError = false;
    },
    validateDeliveryName(state) {
      if (state.deliveryName === "") state.showDeliveryNameError = true;
      else state.showDeliveryNameError = false;
    },
    validateDeliveryUserName(state) {
      if (state.deliveryUserName === "") state.showDeliveryUserNameError = true;
      else state.showDeliveryUserNameError = false;
    },
    validateDeliveryPhoneNumber(state) {
      if (state.deliveryPhoneNumber === "")
        state.showDeliveryPhoneNumberError = true;
      else state.showDeliveryPhoneNumberError = false;
    },
    validateAddress(state) {
      if (
        state.postalCode === "" ||
        state.mainAddress === "" ||
        state.detailAddress === ""
      )
        state.showAddressError = true;
      else state.showAddressError = false;
    },
  },
});
