import { mount } from "@vue/test-utils";
import ReviewAnalysisSummary from "@/components/reviewAnalysis/reviewAnalysisSummary";
import ReviewBox from "@/components/reviewAnalysis/reviewBox";

describe("reviewAnalysisSummary.vue", () => {
  it("AI 리뷰 분석 요약 테스트 (100개 이상)", async () => {
    const wrapper = mount(ReviewAnalysisSummary, {
      propsData: {
        positive: 432,
        negative: 45,
        neutral: 39,
      },
    });

    const summaryWrapper = wrapper.find("div.review-analysis-summary-wrapper");
    const positiveInfoWrapper = summaryWrapper.find(
      "div.review-analysis-summary-gauge-wrapper.positive"
    );
    const positiveGauge = positiveInfoWrapper.find(
      "div.review-analysis-summary-gauge"
    );
    expect(positiveGauge.attributes().style).toContain("width: 127.4px;");
    const positiveCount = positiveInfoWrapper.find(
      "span.review-analysis-summary-review-count"
    );
    expect(positiveCount.text()).toBe("432");

    const negativeInfoWrapper = summaryWrapper.find(
      "div.review-analysis-summary-gauge-wrapper.negative"
    );
    const negativeGauge = negativeInfoWrapper.find(
      "div.review-analysis-summary-gauge"
    );
    expect(negativeGauge.attributes().style).toContain("width: 12.6px;");
    const negativeCount = negativeInfoWrapper.find(
      "span.review-analysis-summary-review-count"
    );
    expect(negativeCount.text()).toBe("45");

    const satisfactionWrapper = summaryWrapper.find(
      "div.review-analysis-summary-satisfaction"
    );
    const satisfactionPercentage = satisfactionWrapper.find("h3");
    expect(satisfactionPercentage.text()).toBe("91%");

    const totalCountWrapper = summaryWrapper.find(
      "div.review-analysis-summary-total-count"
    );
    const totalCount = totalCountWrapper.find("h3");
    expect(totalCount.text()).toBe("100+");
  });

  it("AI 리뷰 분석 요약 테스트 (100개 이하)", async () => {
    const wrapper = mount(ReviewAnalysisSummary, {
      propsData: {
        positive: 17,
        negative: 5,
        neutral: 3,
      },
    });

    const summaryWrapper = wrapper.find("div.review-analysis-summary-wrapper");
    const totalCountWrapper = summaryWrapper.find(
      "div.review-analysis-summary-total-count"
    );
    const totalCount = totalCountWrapper.find("h3");
    expect(totalCount.text()).toBe("25");
  });
});

describe("reviewBox.vue", () => {
  it("긍정 리뷰", async () => {
    const wrapper = mount(ReviewBox, {
      propsData: {
        type: "positive",
        date: "2021.06.07.",
        text:
          "적극 추천합니다 배송도 엄청 빠릅니다 24평형 방세개 청소기 돌리는데 30분 정도 사용됩니다.",
      },
    });

    const reviewBoxWrapper = wrapper.find("div.review-analysis-box-wrapper");
    const reviewBoxTagWrapper = reviewBoxWrapper.find(
      "div.review-analysis-box-tag-wrapper"
    );
    const reviewTagImg = reviewBoxTagWrapper.find("img");
    expect(reviewTagImg.attributes().src).toEqual(
      "https://nosearch.com/static/images/positive_smile.png"
    );
    const reviewTagSpan = reviewBoxTagWrapper.find("span");
    expect(reviewTagSpan.text()).toBe("긍정 리뷰");
    expect(reviewTagSpan.attributes().style).toContain(
      "color: rgb(97, 145, 255);"
    );
    const reviewDate = reviewBoxWrapper.find(
      "span.review-analysis-box-tag-date"
    );
    expect(reviewDate.text()).toBe("2021.06 작성");
  });

  it("부정 리뷰", async () => {
    const wrapper = mount(ReviewBox, {
      propsData: {
        type: "negative",
        date: "2021.06.07.",
        text:
          "배송 온 박스는 누가 반품한 거 보냈는지 아니면 장기간 방치된 재고인지 많이 오염되어 왔습니다. 제품 성능은 기대 이하입니다. 반품하고 싶지만 그냥 쓰겠습니다.",
      },
    });

    const reviewBoxWrapper = wrapper.find("div.review-analysis-box-wrapper");
    const reviewBoxTagWrapper = reviewBoxWrapper.find(
      "div.review-analysis-box-tag-wrapper"
    );
    const reviewTagImg = reviewBoxTagWrapper.find("img");
    expect(reviewTagImg.attributes().src).toEqual(
      "https://nosearch.com/static/images/negative_upset.png"
    );
    const reviewTagSpan = reviewBoxTagWrapper.find("span");
    expect(reviewTagSpan.text()).toBe("부정 리뷰");
    expect(reviewTagSpan.attributes().style).toContain(
      "color: rgb(255, 104, 97);"
    );
  });
});
